==================
Usage and Examples
==================

.. toctree::
    :maxdepth: 1
    :caption: Example notebooks and usage guides:

    examples/get_rm_from_altaz.ipynb
    examples/get_rm_from_skycoord.ipynb
    examples/get_rm_from_ms.ipynb
    examples/get_rm_from_fits.ipynb
    examples/how_to_download.ipynb
    examples/iono_options.ipynb
    cli
